@@ -15,16 +15,14 @@
 # was previously in Bio.WWW.SCOP, has now been merged into this module.
 
 
-""" SCOP: Structural Classification of Proteins.
+"""SCOP: Structural Classification of Proteins.
 
 The SCOP database aims to provide a manually constructed classification of
 all know protein structures into a hierarchy, the main levels of which
 are family, superfamily and fold.
 
 * "SCOP":http://scop.mrc-lmb.cam.ac.uk/scop/
-
 * "Introduction":http://scop.mrc-lmb.cam.ac.uk/scop/intro.html
-
 * "SCOP parsable files":http://scop.mrc-lmb.cam.ac.uk/scop/parse/
 
 The Scop object in this module represents the entire SCOP classification. It
@@ -33,8 +31,7 @@ converted back to the same file formats. A single SCOP domain (represented
 by the Domain class) can be obtained from Scop using the domain's SCOP
 identifier (sid).
 
-
-nodeCodeDict  -- A mapping between known 2 letter node codes and a longer
+- nodeCodeDict -- A mapping between known 2 letter node codes and a longer
                   description. The known node types are 'cl' (class), 'cf'
                   (fold), 'sf' (superfamily), 'fa' (family), 'dm' (domain),
                   'sp' (species), 'px' (domain). Additional node types may
@@ -43,8 +40,8 @@ nodeCodeDict  -- A mapping between known 2 letter node codes and a longer
 This module also provides code to access SCOP over the WWW.
 
 Functions:
-search        -- Access the main CGI script.
-_open         -- Internally used function.
+ - search        -- Access the main CGI script.
+ - _open         -- Internally used function.
 
 """
 
@@ -90,7 +87,7 @@ try:
     _cmp = cmp
 except NameError:
     def _cmp(a, b):
-        """Implementation of cmp(x,y) for Python 3 (PRIVATE).
+        """Implement cmp(x,y) for Python 3 (PRIVATE).
 
         Based on Python 3 docs which say if you really need the cmp()
         functionality, you could use the expression (a > b) -  (a < b)
@@ -162,6 +159,7 @@ class Scop(object):
 
     root -- The root node of the hierarchy
     """
+
     def __init__(self, cla_handle=None, des_handle=None, hie_handle=None,
                  dir_path=None, db_handle=None, version=None):
         """Build the SCOP hierarchy from the SCOP parsable files, or a sql backend.
@@ -276,10 +274,11 @@ class Scop(object):
                     hie_handle.close()
 
     def getRoot(self):
+        """Get root node."""
         return self.getNodeBySunid(0)
 
     def getDomainBySid(self, sid):
-        """Return a domain from its sid"""
+        """Return a domain from its sid."""
         if sid in self._sidDict:
             return self._sidDict[sid]
         if self.db_handle:
@@ -290,7 +289,7 @@ class Scop(object):
             return None
 
     def getNodeBySunid(self, sunid):
-        """Return a node from its sunid"""
+        """Return a node from its sunid."""
         if sunid in self._sunidDict:
             return self._sunidDict[sunid]
         if self.db_handle:
@@ -301,33 +300,33 @@ class Scop(object):
             return None
 
     def getDomains(self):
-        """Returns an ordered tuple of all SCOP Domains"""
+        """Return an ordered tuple of all SCOP Domains."""
         if self.db_handle:
             return self.getRoot().getDescendents('px')
         else:
             return self._domains
 
     def write_hie(self, handle):
-        """Build an HIE SCOP parsable file from this object"""
+        """Build an HIE SCOP parsable file from this object."""
         # We order nodes to ease comparison with original file
         for n in sorted(self._sunidDict.values(), key=lambda n: n.sunid):
             handle.write(str(n.toHieRecord()))
 
     def write_des(self, handle):
-        """Build a DES SCOP parsable file from this object"""
+        """Build a DES SCOP parsable file from this object."""
         # Original SCOP file is not ordered?
         for n in sorted(self._sunidDict.values(), key=lambda n: n.sunid):
             if n != self.root:
                 handle.write(str(n.toDesRecord()))
 
     def write_cla(self, handle):
-        """Build a CLA SCOP parsable file from this object"""
+        """Build a CLA SCOP parsable file from this object."""
         # We order nodes to ease comparison with original file
         for n in sorted(self._sidDict.values(), key=lambda n: n.sunid):
             handle.write(str(n.toClaRecord()))
 
     def getDomainFromSQL(self, sunid=None, sid=None):
-        """Load a node from the SQL backend using sunid or sid"""
+        """Load a node from the SQL backend using sunid or sid."""
         if sunid is None and sid is None:
             return None
 
@@ -358,14 +357,14 @@ class Scop(object):
             else:
                 n = Domain(scop=self)
                 cur.execute("select sid, residues, pdbid from cla where sunid=%s",
-                               sunid)
+                            sunid)
 
-                [n.sid, n.residues, pdbid] = cur.fetchone()
+                n.sid, n.residues, pdbid = cur.fetchone()
                 n.residues = Residues.Residues(n.residues)
                 n.residues.pdbid = pdbid
                 self._sidDict[n.sid] = n
 
-            [n.sunid, n.type, n.sccs, n.description] = data
+            n.sunid, n.type, n.sccs, n.description = data
 
             if data[1] != 'ro':
                 cur.execute("SELECT parent FROM hie WHERE child=%s", sunid)
@@ -376,7 +375,7 @@ class Scop(object):
             self._sunidDict[n.sunid] = n
 
     def getAscendentFromSQL(self, node, type):
-        """Get ascendents using SQL backend"""
+        """Get ascendents using SQL backend."""
         if nodeCodeOrder.index(type) >= nodeCodeOrder.index(node.type):
             return None
 
@@ -389,9 +388,10 @@ class Scop(object):
             return None
 
     def getDescendentsFromSQL(self, node, type):
-        """Get descendents of a node using the database backend.  This avoids
-        repeated iteration of SQL calls and is therefore much quicker than
-        repeatedly calling node.getChildren().
+        """Get descendents of a node using the database backend.
+
+        This avoids repeated iteration of SQL calls and is therefore much
+        quicker than repeatedly calling node.getChildren().
         """
         if nodeCodeOrder.index(type) <= nodeCodeOrder.index(node.type):
             return []
@@ -414,7 +414,7 @@ class Scop(object):
             for d in data:
                 if int(d[0]) not in self._sunidDict:
                     n = Node(scop=self)
-                    [n.sunid, n.type, n.sccs, n.description] = d
+                    n.sunid, n.type, n.sccs, n.description = d
                     n.sunid = int(n.sunid)
                     self._sunidDict[n.sunid] = n
 
@@ -438,10 +438,7 @@ class Scop(object):
             for d in data:
                 if int(d[0]) not in self._sunidDict:
                     n = Domain(scop=self)
-                    # [n.sunid, n.sid, n.pdbid, n.residues, n.sccs, n.type,
-                    # n.description,n.parent] = data
-                    [n.sunid, n.sid, pdbid, n.residues, n.sccs, n.type, n.description,
-                     n.parent] = d[0:8]
+                    n.sunid, n.sid, pdbid, n.residues, n.sccs, n.type, n.description, n.parent = d[0:8]
                     n.residues = Residues.Residues(n.residues)
                     n.residues.pdbid = pdbid
                     n.sunid = int(n.sunid)
@@ -453,7 +450,7 @@ class Scop(object):
         return des_list
 
     def write_hie_sql(self, handle):
-        """Write HIE data to SQL database"""
+        """Write HIE data to SQL database."""
         cur = handle.cursor()
 
         cur.execute("DROP TABLE IF EXISTS hie")
@@ -465,7 +462,7 @@ class Scop(object):
                 cur.execute("INSERT INTO hie VALUES (%s,%s)" % (p.sunid, c.sunid))
 
     def write_cla_sql(self, handle):
-        """Write CLA data to SQL database"""
+        """Write CLA data to SQL database."""
         cur = handle.cursor()
 
         cur.execute("DROP TABLE IF EXISTS cla")
@@ -476,14 +473,14 @@ class Scop(object):
         for n in self._sidDict.values():
             c = n.toClaRecord()
             cur.execute("INSERT INTO cla VALUES (%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s)",
-                         (n.sunid, n.sid, c.residues.pdbid, c.residues, n.sccs,
+                        (n.sunid, n.sid, c.residues.pdbid, c.residues, n.sccs,
                          n.getAscendent('cl').sunid, n.getAscendent('cf').sunid,
                          n.getAscendent('sf').sunid, n.getAscendent('fa').sunid,
                          n.getAscendent('dm').sunid, n.getAscendent('sp').sunid,
                          n.sunid))
 
     def write_des_sql(self, handle):
-        """Write DES data to SQL database"""
+        """Write DES data to SQL database."""
         cur = handle.cursor()
 
         cur.execute("DROP TABLE IF EXISTS des")
@@ -493,30 +490,29 @@ class Scop(object):
 
         for n in self._sunidDict.values():
             cur.execute("INSERT INTO des VALUES (%s,%s,%s,%s)",
-                         (n.sunid, n.type, n.sccs, n.description))
+                        (n.sunid, n.type, n.sccs, n.description))
 
 
 class Node(object):
-    """ A node in the Scop hierarchy
+    """A node in the Scop hierarchy.
 
-    sunid  -- SCOP unique identifiers. e.g. '14986'
-
-    parent -- The parent node
-
-    children -- A list of child nodes
-
-    sccs     -- SCOP concise classification string. e.g. 'a.1.1.2'
-
-    type     -- A 2 letter node type code. e.g. 'px' for domains
-
-    description --
+    Attributes:
+     - sunid  -- SCOP unique identifiers. e.g. '14986'
+     - parent -- The parent node
+     - children -- A list of child nodes
+     - sccs     -- SCOP concise classification string. e.g. 'a.1.1.2'
+     - type     -- A 2 letter node type code. e.g. 'px' for domains
+     - description -- Description text.
 
     """
+
     def __init__(self, scop=None):
-        """Create a Node in the scop hierarchy.  If a Scop instance is provided to the
-        constructor, this will be used to lookup related references using the SQL
-        methods.  If no instance is provided, it is assumed the whole tree exists
-        and is connected."""
+        """Initialize a Node in the scop hierarchy.
+
+        If a Scop instance is provided to the constructor, this will be used
+        to lookup related references using the SQL methods.  If no instance
+        is provided, it is assumed the whole tree exists and is connected.
+        """
         self.sunid = ''
         self.parent = None
         self.children = []
@@ -526,6 +522,7 @@ class Node(object):
         self.scop = scop
 
     def __str__(self):
+        """Represent the node as a string."""
         s = []
         s.append(str(self.sunid))
         s.append(self.sccs)
@@ -535,7 +532,7 @@ class Node(object):
         return " ".join(s)
 
     def toHieRecord(self):
-        """Return an Hie.Record"""
+        """Return an Hie.Record."""
         rec = Hie.Record()
         rec.sunid = str(self.sunid)
         if self.getParent():  # Not root node
@@ -547,7 +544,7 @@ class Node(object):
         return rec
 
     def toDesRecord(self):
-        """Return a Des.Record"""
+        """Return a Des.Record."""
         rec = Des.Record()
         rec.sunid = str(self.sunid)
         rec.nodetype = self.type
@@ -556,22 +553,24 @@ class Node(object):
         return rec
 
     def getChildren(self):
-        """Return a list of children of this Node"""
+        """Return a list of children of this Node."""
         if self.scop is None:
             return self.children
         else:
             return [self.scop.getNodeBySunid(x) for x in self.children]
 
     def getParent(self):
-        """Return the parent of this Node"""
+        """Return the parent of this Node."""
         if self.scop is None:
             return self.parent
         else:
             return self.scop.getNodeBySunid(self.parent)
 
     def getDescendents(self, node_type):
-        """ Return a list of all descendant nodes of the given type. Node type can a
-        two letter code or longer description. e.g. 'fa' or 'family'
+        """Return a list of all descendant nodes of the given type.
+
+        Node type can be a two letter code or longer description,
+        e.g. 'fa' or 'family'.
         """
         if node_type in _nodetype_to_code:
             node_type = _nodetype_to_code[node_type]
@@ -591,8 +590,11 @@ class Node(object):
         return nodes
 
     def getAscendent(self, node_type):
-        """ Return the ancenstor node of the given type, or None.Node type can a
-        two letter code or longer description. e.g. 'fa' or 'family'"""
+        """Return the ancenstor node of the given type, or None.
+
+        Node type can be a two letter code or longer description,
+        e.g. 'fa' or 'family'.
+        """
         if node_type in _nodetype_to_code:
             node_type = _nodetype_to_code[node_type]
 
@@ -612,19 +614,23 @@ class Node(object):
 
 
 class Domain(Node):
-    """ A SCOP domain. A leaf node in the Scop hierarchy.
+    """A SCOP domain. A leaf node in the Scop hierarchy.
 
-        - sid      -- The SCOP domain identifier. e.g. ``"d5hbib_"``
+    Attributes:
+        - sid - The SCOP domain identifier. e.g. ``"d5hbib_"``
+        - residues - A Residue object. It defines the collection of PDB
+          atoms that make up this domain.
 
-        - residues -- A Residue object. It defines the collection
-          of PDB atoms that make up this domain.
     """
+
     def __init__(self, scop=None):
+        """Initialize a SCOP Domain object."""
         Node.__init__(self, scop=scop)
         self.sid = ''
         self.residues = None
 
     def __str__(self):
+        """Represent the SCOP Domain as a string."""
         s = []
         s.append(self.sid)
         s.append(self.sccs)
@@ -641,13 +647,13 @@ class Domain(Node):
         return " ".join(s)
 
     def toDesRecord(self):
-        """Return a Des.Record"""
+        """Return a Des.Record."""
         rec = Node.toDesRecord(self)
         rec.name = self.sid
         return rec
 
     def toClaRecord(self):
-        """Return a Cla.Record"""
+        """Return a Cla.Record."""
         rec = Cla.Record()
         rec.sid = self.sid
         rec.residues = self.residues
@@ -667,29 +673,29 @@ class Domain(Node):
 
 
 class Astral(object):
-    """Abstraction of the ASTRAL database, which has sequences for all the SCOP domains,
+    """Representation of the ASTRAL database.
+
+    Abstraction of the ASTRAL database, which has sequences for all the SCOP domains,
     as well as clusterings by percent id or evalue.
     """
 
     def __init__(self, dir_path=None, version=None, scop=None,
-                  astral_file=None, db_handle=None):
-        """Initialise the astral database.
+                 astral_file=None, db_handle=None):
+        """Initialize the astral database.
 
         You must provide either a directory of SCOP files:
-
             - dir_path - string, the path to location of the scopseq-x.xx directory
                        (not the directory itself), and
             - version   -a version number.
 
         or, a FASTA file:
-
             - astral_file - string, a path to a fasta file (which will be loaded in memory)
 
         or, a MYSQL database:
-
             - db_handle - a database handle for a MYSQL database containing a table
               'astral' with the astral data in it.  This can be created
               using writeToSQL.
+
         """
         if astral_file is None and dir_path is None and db_handle is None:
             raise RuntimeError("Need either file handle, or (dir_path + version),"
@@ -720,7 +726,7 @@ class Astral(object):
         self.IdDatahash = {}
 
     def domainsClusteredByEv(self, id):
-        """get domains clustered by evalue"""
+        """Get domains clustered by evalue."""
         if id not in self.EvDatasets:
             if self.db_handle:
                 self.EvDatasets[id] = self.getAstralDomainsFromSQL(astralEv_to_sql[id])
@@ -737,7 +743,7 @@ class Astral(object):
         return self.EvDatasets[id]
 
     def domainsClusteredById(self, id):
-        """get domains clustered by percent id"""
+        """Get domains clustered by percentage identity."""
         if id not in self.IdDatasets:
             if self.db_handle:
                 self.IdDatasets[id] = self.getAstralDomainsFromSQL("id" + str(id))
@@ -752,7 +758,7 @@ class Astral(object):
         return self.IdDatasets[id]
 
     def getAstralDomainsFromFile(self, filename=None, file_handle=None):
-        """Get the scop domains from a file containing a list of sids"""
+        """Get the scop domains from a file containing a list of sids."""
         if file_handle is None and filename is None:
             raise RuntimeError("You must provide a filename or handle")
         if not file_handle:
@@ -772,8 +778,11 @@ class Astral(object):
         return doms
 
     def getAstralDomainsFromSQL(self, column):
-        """Load a set of astral domains from a column in the astral table of a MYSQL
-        database (which can be created with writeToSQL(...)"""
+        """Load ASTRAL domains from the MySQL database.
+
+        Load a set of astral domains from a column in the astral table of a MYSQL
+        database (which can be created with writeToSQL(...).
+        """
         cur = self.db_handle.cursor()
         cur.execute("SELECT sid FROM astral WHERE " + column + "=1")
         data = cur.fetchall()
@@ -782,7 +791,7 @@ class Astral(object):
         return data
 
     def getSeqBySid(self, domain):
-        """get the seq record of a given domain from its sid"""
+        """Get the seq record of a given domain from its sid."""
         if self.db_handle is None:
             return self.fasta_dict[domain].seq
         else:
@@ -791,11 +800,11 @@ class Astral(object):
             return Seq(cur.fetchone()[0])
 
     def getSeq(self, domain):
-        """Return seq associated with domain"""
+        """Return seq associated with domain."""
         return self.getSeqBySid(domain.sid)
 
     def hashedDomainsById(self, id):
-        """Get domains clustered by sequence identity in a dict"""
+        """Get domains clustered by sequence identity in a dict."""
         if id not in self.IdDatahash:
             self.IdDatahash[id] = {}
             for d in self.domainsClusteredById(id):
@@ -803,7 +812,7 @@ class Astral(object):
         return self.IdDatahash[id]
 
     def hashedDomainsByEv(self, id):
-        """Get domains clustered by evalue in a dict"""
+        """Get domains clustered by evalue in a dict."""
         if id not in self.EvDatahash:
             self.EvDatahash[id] = {}
             for d in self.domainsClusteredByEv(id):
@@ -811,15 +820,15 @@ class Astral(object):
         return self.EvDatahash[id]
 
     def isDomainInId(self, dom, id):
-        """Returns true if the domain is in the astral clusters for percent ID"""
+        """Return true if the domain is in the astral clusters for percent ID."""
         return dom in self.hashedDomainsById(id)
 
     def isDomainInEv(self, dom, id):
-        """Returns true if the domain is in the ASTRAL clusters for evalues"""
+        """Return true if the domain is in the ASTRAL clusters for evalues."""
         return dom in self.hashedDomainsByEv(id)
 
     def writeToSQL(self, db_handle):
-        """Write the ASTRAL database to a MYSQL database"""
+        """Write the ASTRAL database to a MYSQL database."""
         cur = db_handle.cursor()
 
         cur.execute("DROP TABLE IF EXISTS astral")
@@ -846,8 +855,7 @@ class Astral(object):
 
 def search(pdb=None, key=None, sid=None, disp=None, dir=None, loc=None,
            cgi='http://scop.mrc-lmb.cam.ac.uk/scop/search.cgi', **keywds):
-    """search(pdb=None, key=None, sid=None, disp=None, dir=None, loc=None,
-    cgi='http://scop.mrc-lmb.cam.ac.uk/scop/search.cgi', **keywds)
+    """Access SCOP search and return a handle to the results.
 
     Access search.cgi and return a handle to the results.  See the
     online help file for an explanation of the parameters:
@@ -867,7 +875,7 @@ def search(pdb=None, key=None, sid=None, disp=None, dir=None, loc=None,
 
 
 def _open(cgi, params=None, get=1):
-    """Open a hnadle to SCOP, returns an UndoHandle
+    """Open a handle to SCOP, returns an UndoHandle (PRIVATE).
 
     Open a handle to SCOP.  cgi is the URL for the cgi script to access.
     params is a dictionary with the options to pass to it.  get is a boolean
