@@ -1,5 +1,5 @@
 # Copyright 2004-2008 by Sebastian Bassi.
-# Copyright 2013 by Markus Piotrowski.
+# Copyright 2013-2018 by Markus Piotrowski.
 # All rights reserved.
 # This code is part of the Biopython distribution and governed by its
 # license.  Please see the LICENSE file that should have been included
@@ -51,7 +51,7 @@ Other public methods of this module:
    correction is not an integral part of the Tm methods and must
    be called additionally.
 
-Examples:
+For example:
 
     >>> from Bio.SeqUtils import MeltingTemp as mt
     >>> from Bio.Seq import Seq
@@ -78,6 +78,13 @@ Using different thermodynamic tables, e.g. from Breslauer '86 or Sugimoto '96:
     >>> print('%0.2f' % mt.Tm_NN(myseq, nn_table=mt.DNA_NN2))  # Sugimoto '96
     65.47
 
+Tables for RNA and RNA/DNA hybrids are included:
+
+    >>> print('%0.2f' % mt.Tm_NN(myseq, nn_table=mt.RNA_NN1))  # Freier '86
+    73.35
+    >>> print('%0.2f' % mt.Tm_NN(myseq, nn_table=mt.R_DNA_NN1))  # Sugimoto '95
+    57.17
+
 Several types of salc correction (for Tm_NN and Tm_GC):
 
     >>> for i in range(1, 8):
@@ -257,12 +264,12 @@ R_DNA_NN1 = {
     'init': (1.9, -3.9), 'init_A/T': (0, 0), 'init_G/C': (0, 0),
     'init_oneG/C': (0, 0), 'init_allA/T': (0, 0), 'init_5T/A': (0, 0),
     'sym': (0, 0),
-    'AA': (-11.5, -36.4), 'AC': (-7.8, -21.6), 'AG': (-7.0, -19.7),
-    'AT': (-8.3, -23.9), 'CA': (-10.4, -28.4), 'CC': (-12.8, -31.9),
-    'CG': (-16.3, -47.1), 'CT': (-9.1, -23.5), 'GA': (-8.6, -22.9),
-    'GC': (-8.0, -17.1), 'GG': (-9.3, -23.2), 'GT': (-5.9, -12.3),
-    'TA': (-7.8, -23.2), 'TC': (-5.5, -13.5), 'TG': (-9.0, -26.1),
-    'TT': (-7.8, -21.9)}
+    'AA/TT': (-11.5, -36.4), 'AC/TG': (-7.8, -21.6), 'AG/TC': (-7.0, -19.7),
+    'AT/TA': (-8.3, -23.9), 'CA/GT': (-10.4, -28.4), 'CC/GG': (-12.8, -31.9),
+    'CG/GC': (-16.3, -47.1), 'CT/GA': (-9.1, -23.5), 'GA/CT': (-8.6, -22.9),
+    'GC/CG': (-8.0, -17.1), 'GG/CC': (-9.3, -23.2), 'GT/CA': (-5.9, -12.3),
+    'TA/AT': (-7.8, -23.2), 'TC/AG': (-5.5, -13.5), 'TG/AC': (-9.0, -26.1),
+    'TT/AA': (-7.8, -21.9)}
 
 # Internal mismatch and inosine table (DNA)
 # Allawi & SantaLucia (1997), Biochemistry 36: 10581-10594
@@ -411,7 +418,7 @@ def make_table(oldtable=None, values=None):
 
 
 def _check(seq, method):
-    """Return a sequence which fullfils the requirements of the given method.
+    """Return a sequence which fullfils the requirements of the given method (PRIVATE).
 
     All Tm methods in this package require the sequence in uppercase format.
     Most methods make use of the length of the sequence (directly or
@@ -448,7 +455,7 @@ def salt_correction(Na=0, K=0, Tris=0, Mg=0, dNTPs=0, method=1, seq=None):
     calculate corrected Tm values, different operations need to be applied:
 
      - methods 1-4: Tm(new) = Tm(old) + corr
-     - method 5: deltaH(new) = deltaH(old) + corr
+     - method 5: deltaS(new) = deltaS(old) + corr
      - methods 6+7: Tm(new) = 1/(1/Tm(old) + corr)
 
     Parameters:
@@ -477,18 +484,17 @@ def salt_correction(Na=0, K=0, Tris=0, Mg=0, dNTPs=0, method=1, seq=None):
           Mg2+ is corrected for dNTPs binding (if present)
           (Owczarzy et al. (2008), Biochemistry 47: 5336-5353)
 
-    Examples:
-
-        >>> from Bio.SeqUtils import MeltingTemp as mt
-        >>> print('%0.2f' % mt.salt_correction(Na=50, method=1))
-        -21.60
-        >>> print('%0.2f' % mt.salt_correction(Na=50, method=2))
-        -21.85
-        >>> print('%0.2f' % mt.salt_correction(Na=100, Tris=20, method=2))
-        -16.45
-        >>> print('%0.2f' % mt.salt_correction(Na=100, Tris=20, Mg=1.5,
-        ...                                    method=2))
-        -10.99
+    Examples
+    --------
+    >>> from Bio.SeqUtils import MeltingTemp as mt
+    >>> print('%0.2f' % mt.salt_correction(Na=50, method=1))
+    -21.60
+    >>> print('%0.2f' % mt.salt_correction(Na=50, method=2))
+    -21.85
+    >>> print('%0.2f' % mt.salt_correction(Na=100, Tris=20, method=2))
+    -16.45
+    >>> print('%0.2f' % mt.salt_correction(Na=100, Tris=20, Mg=1.5, method=2))
+    -10.99
 
     """
     if method in (5, 6, 7) and not seq:
@@ -579,7 +585,6 @@ def chem_correction(melting_temp, DMSO=0, fmd=0, DMSOfactor=0.75,
      - GC: GC content in percent.
 
     Examples:
-
         >>> from Bio.SeqUtils import MeltingTemp as mt
         >>> mt.chem_correction(70)
         70
@@ -622,7 +627,6 @@ def Tm_Wallace(seq, check=True, strict=True):
     Non-DNA characters (e.g., E, F, J, !, 1, etc) are ignored by this method.
 
     Examples:
-
         >>> from Bio.SeqUtils import MeltingTemp as mt
         >>> mt.Tm_Wallace('ACGTTGCAATGCCGTA')
         48.0
@@ -708,7 +712,7 @@ def Tm_GC(seq, check=True, strict=True, valueset=7, userset=None, Na=50, K=0,
 
     """
     if saltcorr == 5:
-        raise ValueError('salt-correction method 5 not applicable' +
+        raise ValueError('salt-correction method 5 not applicable '
                          'to Tm_GC')
     seq = str(seq)
     if check:
@@ -719,8 +723,8 @@ def Tm_GC(seq, check=True, strict=True, valueset=7, userset=None, Na=50, K=0,
         sum(map(seq.count, ('B', 'V'))) * 66.67 / len(seq) + \
         sum(map(seq.count, ('D', 'H'))) * 33.33 / len(seq)
     if strict and tmp:
-        raise ValueError('ambiguous bases B, D, H, K, M, N, R, V, Y not ' +
-                         'allowed when strict=True')
+        raise ValueError('ambiguous bases B, D, H, K, M, N, R, V, Y not '
+                         'allowed when \'strict=True\'')
     else:
         percent_gc += tmp
     if userset:
@@ -763,7 +767,7 @@ def Tm_GC(seq, check=True, strict=True, valueset=7, userset=None, Na=50, K=0,
 
 
 def _key_error(neighbors, strict):
-    """Throw an error or a warning if there is no data for the neighbors."""
+    """Throw an error or a warning if there is no data for the neighbors (PRIVATE)."""
     # We haven't found the key in the tables
     if strict:
         raise ValueError('no thermodynamic data for neighbors \'' + neighbors +
@@ -814,6 +818,7 @@ def Tm_NN(seq, check=True, strict=True, c_seq=None, shift=0, nn_table=DNA_NN3,
        For RNA/DNA hybridizations:
 
         - R_DNA_NN1: values from Sugimoto et al. (1995)
+          Note that ``seq`` must be the RNA sequence.
 
        Use the module's maketable method to make a new table or to update one
        one of the implemented tables.
@@ -987,7 +992,7 @@ def Tm_NN(seq, check=True, strict=True, c_seq=None, shift=0, nn_table=DNA_NN3,
 
 
 def Tm_staluc(s, dnac=50, saltc=50, rna=0):
-    """Returns DNA/DNA Tm using nearest neighbor thermodynamics (OBSOLETE).
+    """Return DNA/DNA Tm using nearest neighbor thermodynamics (OBSOLETE).
 
     This method may be depreceated in the future. Use Tm_NN instead. Tm_NN
     with default values gives the same result as Tm_staluc.
@@ -1000,8 +1005,8 @@ def Tm_staluc(s, dnac=50, saltc=50, rna=0):
     For DNA/DNA, see Allawi & SantaLucia (1997), Biochemistry 36: 10581-10594
     For RNA/RNA, see Xia et al (1998), Biochemistry 37: 14719-14735
 
-    Example:
-
+    Examples
+    --------
     >>> print("%0.2f" % Tm_staluc('CAGTCAGTACGTACGTGTACTGCCGTA'))
     59.87
     >>> print("%0.2f" % Tm_staluc('CAGTCAGTACGTACGTGTACTGCCGTA', rna=True))
