@@ -3,8 +3,7 @@
 # as part of this package.
 #
 
-"""Command line wrapper for bwa
-"""
+"""Command line wrapper for bwa."""
 
 from __future__ import print_function
 from Bio._py3k import basestring
@@ -22,9 +21,8 @@ class BwaIndexCommandline(AbstractCommandline):
 
     See http://bio-bwa.sourceforge.net/bwa.shtml for details.
 
-    Example
-    -------
-
+    Examples
+    --------
     >>> from Bio.Sequencing.Applications import BwaIndexCommandline
     >>> reference_genome = "/path/to/reference_genome.fasta"
     >>> index_cmd = BwaIndexCommandline(infile=reference_genome, algorithm="bwtsw")
@@ -35,7 +33,9 @@ class BwaIndexCommandline(AbstractCommandline):
     Python subprocess module, as described in the Biopython tutorial.
 
     """
+
     def __init__(self, cmd="bwa", **kwargs):
+        """Initialize the class."""
         self.program_name = cmd
         self.parameters = [
             _StaticArgument("index"),
@@ -71,21 +71,23 @@ class BwaAlignCommandline(AbstractCommandline):
 
     See http://bio-bwa.sourceforge.net/bwa.shtml for details.
 
-    Example:
-
+    Examples
+    --------
     >>> from Bio.Sequencing.Applications import BwaAlignCommandline
     >>> reference_genome = "/path/to/reference_genome.fasta"
     >>> read_file = "/path/to/read_1.fq"
     >>> output_sai_file = "/path/to/read_1.sai"
-    >>> read_group="@RG\tID:foo\tSM:bar"
     >>> align_cmd = BwaAlignCommandline(reference=reference_genome, read_file=read_file)
     >>> print(align_cmd)
     bwa aln /path/to/reference_genome.fasta /path/to/read_1.fq
 
     You would typically run the command line using align_cmd(stdout=output_sai_file)
     or via the Python subprocess module, as described in the Biopython tutorial.
+
     """
+
     def __init__(self, cmd="bwa", **kwargs):
+        """Initialize the class."""
         self.program_name = cmd
         self.parameters = [
             _StaticArgument("aln"),
@@ -182,8 +184,8 @@ class BwaSamseCommandline(AbstractCommandline):
 
     See http://bio-bwa.sourceforge.net/bwa.shtml for details.
 
-    Example:
-
+    Examples
+    --------
     >>> from Bio.Sequencing.Applications import BwaSamseCommandline
     >>> reference_genome = "/path/to/reference_genome.fasta"
     >>> read_file = "/path/to/read_1.fq"
@@ -196,8 +198,11 @@ class BwaSamseCommandline(AbstractCommandline):
 
     You would typically run the command line using samse_cmd(stdout=output_sam_file)
     or via the Python subprocess module, as described in the Biopython tutorial.
+
     """
+
     def __init__(self, cmd="bwa", **kwargs):
+        """Initialize the class."""
         self.program_name = cmd
         self.parameters = [
             _StaticArgument("samse"),
@@ -219,7 +224,7 @@ class BwaSamseCommandline(AbstractCommandline):
 
 
 class BwaSampeCommandline(AbstractCommandline):
-    """Command line wrapper for Burrows Wheeler Aligner (BWA) sampe.
+    r"""Command line wrapper for Burrows Wheeler Aligner (BWA) sampe.
 
     Generate alignments in the SAM format given paired-end reads.
     Equivalent to::
@@ -228,8 +233,8 @@ class BwaSampeCommandline(AbstractCommandline):
 
     See http://bio-bwa.sourceforge.net/bwa.shtml for details.
 
-    Example:
-
+    Examples
+    --------
     >>> from Bio.Sequencing.Applications import BwaSampeCommandline
     >>> reference_genome = "/path/to/reference_genome.fasta"
     >>> read_file1 = "/path/to/read_1.fq"
@@ -237,19 +242,23 @@ class BwaSampeCommandline(AbstractCommandline):
     >>> sai_file1 = "/path/to/read_1.sai"
     >>> sai_file2 = "/path/to/read_2.sai"
     >>> output_sam_file = "/path/to/output.sam"
-    >>> read_group = "@RG\tID:foo\tSM:bar"
+    >>> read_group = r"@RG\tID:foo\tSM:bar"  # BWA will turn backslash-t into tab
     >>> sampe_cmd = BwaSampeCommandline(reference=reference_genome,
     ...                                 sai_file1=sai_file1, sai_file2=sai_file2,
     ...                                 read_file1=read_file1, read_file2=read_file2,
     ...                                 r=read_group)
     >>> print(sampe_cmd)
-    bwa sampe /path/to/reference_genome.fasta /path/to/read_1.sai /path/to/read_2.sai /path/to/read_1.fq /path/to/read_2.fq -r @RG       ID:foo  SM:bar
+    bwa sampe /path/to/reference_genome.fasta /path/to/read_1.sai /path/to/read_2.sai /path/to/read_1.fq /path/to/read_2.fq -r @RG\tID:foo\tSM:bar
 
     You would typically run the command line using sampe_cmd(stdout=output_sam_file)
     or via the Python subprocess module, as described in the Biopython tutorial.
+
     """
+
     # TODO - Should the read group have a raw tab in it, or \t?
+
     def __init__(self, cmd="bwa", **kwargs):
+        """Initialize the class."""
         self.program_name = cmd
         self.parameters = [
             _StaticArgument("sampe"),
@@ -300,8 +309,8 @@ class BwaBwaswCommandline(AbstractCommandline):
 
     See http://bio-bwa.sourceforge.net/bwa.shtml for details.
 
-    Example:
-
+    Examples
+    --------
     >>> from Bio.Sequencing.Applications import BwaBwaswCommandline
     >>> reference_genome = "/path/to/reference_genome.fasta"
     >>> read_file = "/path/to/read_1.fq"
@@ -311,8 +320,11 @@ class BwaBwaswCommandline(AbstractCommandline):
 
     You would typically run the command line using bwasw_cmd() or via the
     Python subprocess module, as described in the Biopython tutorial.
+
     """
+
     def __init__(self, cmd="bwa", **kwargs):
+        """Initialize the class."""
         self.program_name = cmd
         self.parameters = [
             _StaticArgument("bwasw"),
